@@ -108,6 +108,8 @@ def chapterHeading(html_source, verbose, language_code):
     
     if language_code == 'nl':
         chapter = 'Hoofdstuk [number]'
+    elif language_code == 'bg':
+        chapter = 'глава [number]'
     elif language_code == 'ca':
         chapter = 'Cap&iacute;tol [number]'
     elif language_code == 'da':
@@ -515,7 +517,7 @@ def generatePDF(html_source, verbose, language_code='en', pdf_parameter='openpdf
 
     pdf = pisa.CreatePDF(
         html_source,
-        file(file_name, "wb"))
+        file(file_name, "wb"), None, None, 0, False, None, False, None, None, False)
     
     if not pdf.err and pdf_parameter=='openpdf':
             pisa.startViewer(file_name)
@@ -531,6 +533,8 @@ def createHandbook(language_code, download_images='missing', pdf='openpdf', verb
     if language_code == 'en':
         url = 'http://musescore.org/en/print/book/export/html/51'
         internal = 'http://musescore.org/en/handbook'
+    elif language_code == 'bg':
+        url = 'http://musescore.org/bg/print/book/export/html/5246'
     elif language_code == 'ca':
         url = 'http://musescore.org/ca/print/book/export/html/3414'
         internal = 'http://musescore.org/ca/manual'
@@ -629,7 +633,7 @@ def createHandbook(language_code, download_images='missing', pdf='openpdf', verb
 
 
 def main():
-    language_choices = ['all','en','ca','da','de','el','es','fi','fr','gl','hu','it','ja','nb','nl','pl','pt-BR','ro','ru', 'zh-hans']
+    language_choices = ['all','en','bg','da','de','el','es','fi','fr','gl','hu','it','ja','nb','nl','pl','pt-BR','ro','ru', 'zh-hans']
   
     parser = OptionParser()
     parser.add_option("-l","--lang", dest="language_code",
