@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: actions.cpp 3975 2011-02-02 12:36:44Z lasconic $
+//  $Id: actions.cpp 4455 2011-07-01 15:23:33Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -2133,6 +2133,39 @@ Shortcut MuseScore::sc[] = {
          QT_TRANSLATE_NOOP("action","Parts..."),
          QT_TRANSLATE_NOOP("action","Parts...")
          ),
+      Shortcut(
+         STATE_NORMAL,
+         "next-score",
+         QT_TRANSLATE_NOOP("action","next score"),
+         QKeySequence::NextChild,
+         Qt::ApplicationShortcut,
+         QT_TRANSLATE_NOOP("action","next score"),
+         QT_TRANSLATE_NOOP("action","next score")
+         ),
+      Shortcut(
+         STATE_NORMAL,
+         "previous-score",
+         QT_TRANSLATE_NOOP("action","previous score"),
+#if defined(Q_WS_WIN)
+          // Qt bug on windows : http://bugreports.qt.nokia.com/browse/QTBUG-15746
+         Qt::CTRL+Qt::SHIFT+Qt::Key_Tab,
+#else         
+         QKeySequence::PreviousChild,
+#endif
+         Qt::ApplicationShortcut,
+         QT_TRANSLATE_NOOP("action","previous score"),
+         QT_TRANSLATE_NOOP("action","previous score")
+         ),
+      Shortcut(
+         STATE_INIT | STATE_DISABLED | STATE_NORMAL | STATE_NOTE_ENTRY | STATE_EDIT | STATE_PLAY | STATE_SEARCH,
+         "musescore-connect",
+         "MuseScore Connect",
+         Qt::Key_F7,
+         Qt::ApplicationShortcut,
+         "MuseScore Connect",
+         "MuseScore Connect",
+         community_ICON
+         ),
       // xml==0  marks end of list
       Shortcut(0, 0, 0, QKeySequence::UnknownKey),
       };
