@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: barline.cpp 3808 2010-12-24 10:11:39Z lasconic $
+//  $Id: barline.cpp 4527 2011-07-15 10:58:33Z wschweer $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -50,6 +50,8 @@ QPointF BarLine::canvasPos() const
       for (Element* e = parent(); e; e = e->parent())
             xp += e->x();
       System* system = measure()->system();
+      if (system == 0)
+            return QPointF(xp, y());
       double yp = y() + system->staff(staffIdx())->y() + system->y();
       return QPointF(xp, yp);
       }
