@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: chord.cpp 3952 2011-01-26 11:33:22Z lasconic $
+//  $Id: chord.cpp 4464 2011-07-03 15:45:09Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -819,6 +819,8 @@ void Chord::read(QDomElement e, const QList<Tuplet*>& tuplets)
             if (tag == "Note") {
                   Note* note = new Note(score());
                   note->setChord(this);
+                  // the note needs to know the properties of the track it belongs to
+                  note->setTrack(track());
                   note->read(e);
                   add(note);
                   }
