@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: chordproperties.cpp 3203 2010-06-20 17:31:37Z lasconic $
+//  $Id: chordproperties.cpp 4434 2011-06-28 09:51:39Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -44,7 +44,8 @@ ChordProperties::ChordProperties(const Note* note, QWidget* parent)
       //
       static const int heads[] = {
             HEAD_NORMAL, HEAD_CROSS, HEAD_DIAMOND, HEAD_TRIANGLE,
-            HEAD_SLASH, HEAD_XCIRCLE, HEAD_DO, HEAD_RE, HEAD_MI, HEAD_FA, HEAD_LA, HEAD_TI
+            HEAD_SLASH, HEAD_XCIRCLE, HEAD_DO, HEAD_RE, HEAD_MI, HEAD_FA, HEAD_SOL, HEAD_LA, HEAD_TI,
+            HEAD_BREVIS_ALT
             };
       int headGroup = note->headGroup();
       int headGroupIndex = 0;
