@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: edit.cpp 3964 2011-02-01 08:50:00Z lasconic $
+//  $Id: edit.cpp 4574 2011-07-22 15:12:19Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -333,6 +333,121 @@ Note* Score::addNote(Chord* chord, int pitch)
       return note;
       }
 
+//---------------------------------------------------------
+//   replaceTimeSig
+//
+// replaces time signature at tick with TimeSig* ts
+// and adds clones of ts for all remaining staves
+//---------------------------------------------------------
+
+void Score::replaceTimeSig(int tick, TimeSig* ts)
+      {
+      undoFixTicks();
+      //printf(":::replaceTimeSig\n");
+
+      // record old tick lengths, since they will be modified when time is added/removed
+      QVector<int> tickLens;
+      for (Measure* m = firstMeasure(); m; m = m->nextMeasure())
+            tickLens.append(m->tickLen());
+
+      Fraction ofraction(_sigmap->timesig(tick).fraction());
+      Fraction nfraction(TimeSig::getSig(ts->subtype()));
+
+      // find existing timesig and remove it
+      bool notimesig = true;
+      for (Segment* s = firstSegment(); s; s = s->next1()) {
+            if (s->subtype() != SegTimeSig)
+                  continue;
+            int etick = s->tick();
+            if (etick > tick)
+                  break;
+            if (etick == tick) {
+                  for (int staffIdx = 0; staffIdx < _staves.size(); ++staffIdx) {
+                        int track = staffIdx * VOICES;
+                        Element* e = s->element(track);
+                        undoRemoveElement(e);
+                        }
+                  notimesig = false;
+                  break;
+                  }
+            }
+
+      // add new timesig
+      insertTimeSig(tick, ts);
+
+      AL::SigEvent nSig;
+      if (notimesig) {
+            AL::SigEvent nnSig(nfraction);
+            undoChangeSig(tick, AL::SigEvent(), nnSig);
+            }
+      else {
+            AL::SigEvent oSig;
+            AL::iSigEvent i = _sigmap->find(tick);
+            if (i != _sigmap->end()) {
+                  oSig = i->second;
+                  AL::SigEvent e = _sigmap->timesig(tick - 1);
+                  if ((tick == 0) || (e.getNominal() != nfraction)) {
+                        nSig = AL::SigEvent(nfraction);
+                        }
+                  }
+            else {
+                  nSig = AL::SigEvent(nfraction);
+                  }
+
+            undoChangeSig(tick, oSig, nSig);
+            }
+
+      if (ofraction == nfraction && !notimesig)
+            return;
+
+      //---------------------------------------------
+      // remove unnessesary timesig symbols
+      //---------------------------------------------
+
+      int staves = nstaves();
+      for (Segment* segment = firstSegment(); segment;) {
+            Segment* nseg = segment->next1();
+            if (segment->subtype() != SegTimeSig) {
+                  segment = nseg;
+                  continue;
+                  }
+            int etick = segment->tick();
+            if (etick > tick) {
+                  AL::iSigEvent i = _sigmap->find(segment->tick());
+                  if ((etick > tick) && (i->second.fraction() != nfraction))
+                        break;
+                  for (int staffIdx = 0; staffIdx < staves; ++staffIdx) {
+                        Element* e = segment->element(staffIdx * VOICES);
+                        if (e)
+                              undoRemoveElement(e);
+                        }
+                  undoRemoveElement(segment);   // segment is now empty
+                  break;
+                  }
+            segment = nseg;
+            }
+
+      //---------------------------------------------
+      // modify measures
+      //---------------------------------------------
+
+      int j = 0;
+      int ctick = 0;
+      for (Measure* m = firstMeasure(); m; m = m->nextMeasure()) {
+            int newLen = _sigmap->ticksMeasure(ctick);
+            ctick += newLen;
+            int oldLen = tickLens[j];
+            ++j;
+            if (newLen == oldLen)
+                  continue;
+            m->adjustToLen(oldLen, newLen);
+            }
+      //if (nSig.valid())
+      //      insertTimeSig(tick, ts);
+      undoFixTicks();
+
+      }
+
 //---------------------------------------------------------
 //   changeTimeSig
 //
@@ -516,6 +631,34 @@ void Score::cmdRemoveTimeSig(TimeSig* ts)
       undoFixTicks();
       }
 
+//---------------------------------------------------------
+//   insertTimeSig
+//---------------------------------------------------------
+
+void Score::insertTimeSig(int tick, TimeSig* ts)
+      {
+      Measure* measure = tick2measure(tick);
+      for (int staffIdx = 0; staffIdx < nstaves(); ++staffIdx) {
+            TimeSig* nsig = 0;
+            if (staffIdx == 0)
+                  nsig = ts;
+            else
+                  nsig = ts->clone();
+            nsig->setScore(this);
+            nsig->setTrack(staffIdx * VOICES);
+            nsig->setTick(tick);
+            SegmentType st = Segment::segmentType(TIMESIG);
+            Segment* seg = measure->findSegment(st, tick);
+            if (seg == 0) {
+                  seg = measure->createSegment(st, tick);
+                  undoAddElement(seg);
+            }
+            nsig->setParent(seg);
+            undoAddElement(nsig);
+            }
+      layoutAll = true;
+      }
+
 //---------------------------------------------------------
 //   addTimeSig
 //---------------------------------------------------------
@@ -670,64 +813,76 @@ void ScoreView::modifyElement(Element* el)
 
 void Score::cmdAddTie()
       {
-      Note* note = getSelectedNote();
-      if (!note || note->tieFor()) {
-            if (!note)
-                  printf("cmdAddTie: no note selected\n");
-            else
-                  printf("cmdAddTie: has already tie? noteFor: %p\n", note->tieFor());
-            return;
-            }
-      Chord* chord  = note->chord();
-      if (noteEntryMode()) {
-            if (_is.cr() == 0) {
-                  if(debugMode)
-                        printf("cmdAddTie: no pos\n");
-                  expandVoice();
-                  }
-            startCmd();
-            Note* n = addPitch(note->pitch(), false);
-            if (n) {
-                  n->setLine(note->line());
-                  n->setTpc(note->tpc());
-                  Tie* tie = new Tie(this);
-                  tie->setStartNote(note);
-                  tie->setEndNote(n);
-                  tie->setTrack(note->track());
-                  note->setTieFor(tie);
-                  n->setTieBack(tie);
-                  undoAddElement(tie);
-                  nextInputPos(n->chord(), false);
-                  }
-            endCmd();
-            return;
-            }
-      ChordRest* el = nextChordRest(chord);
-      if (el == 0 || el->type() != CHORD) {
-            if (debugMode)
-                  printf("addTie: no next chord found\n");
-            return;
-            }
-      Note* note2 = 0;
-      foreach(Note* n, static_cast<Chord*>(el)->notes()) {
-            if (n->pitch() == note->pitch()) {
-                  note2 = n;
-                  break;
-                  }
-            }
-      if (note2 == 0) {
-            if (debugMode)
-                  printf("addTie: next note for tie not found\n");
+      QList<Note*> noteList;
+      Element* el = selection().element();
+      if (el && el->type() == NOTE)
+            noteList.append(static_cast<Note*>(el));
+      else if (el && el->type() == STEM) {
+            Chord* chord = static_cast<Stem*>(el)->chord();
+            noteList = chord->notes();
+            }
+      else
+            noteList = selection().noteList();
+      if (noteList.isEmpty()) {
+            printf("no notes selected\n");
             return;
             }
+
       startCmd();
-      Tie* tie = new Tie(this);
-      tie->setStartNote(note);
-      tie->setEndNote(note2);
-      tie->setTrack(note->track());
-      undoAddElement(tie);
-      layoutAll = true;
-      select(note2, SELECT_SINGLE, 0);
+      foreach (Note* note, noteList) {
+            if (note->tieFor()) {
+                  printf("cmdAddTie: has already tie? noteFor: %p\n", note->tieFor());
+                  continue;
+                  }
+            Chord* chord  = note->chord();
+            if (noteEntryMode()) {
+                  if (_is.cr() == 0) {
+                        if(debugMode)
+                              printf("cmdAddTie: no pos\n");
+                        expandVoice();
+                        }
+                  Note* n = addPitch(note->pitch(), false);
+                  if (n) {
+                        n->setLine(note->line());
+                        n->setTpc(note->tpc());
+                        Tie* tie = new Tie(this);
+                        tie->setStartNote(note);
+                        tie->setEndNote(n);
+                        tie->setTrack(note->track());
+                        note->setTieFor(tie);
+                        n->setTieBack(tie);
+                        undoAddElement(tie);
+                        nextInputPos(n->chord(), false);
+                        }
+                  layoutAll = true;
+                  continue;
+                  }
+            ChordRest* el = nextChordRest(chord);
+            if (el == 0 || el->type() != CHORD) {
+                  if (debugMode)
+                        printf("addTie: no next chord found\n");
+                  continue;
+                  }
+            Note* note2 = 0;
+            foreach(Note* n, static_cast<Chord*>(el)->notes()) {
+                  if (n->pitch() == note->pitch()) {
+                        note2 = n;
+                        break;
+                        }
+                  }
+            if (note2 == 0) {
+                  if (debugMode)
+                        printf("addTie: next note for tie not found\n");
+                  continue;
+                  }
+            Tie* tie = new Tie(this);
+            tie->setStartNote(note);
+            tie->setEndNote(note2);
+            tie->setTrack(note->track());
+            undoAddElement(tie);
+            layoutAll = true;
+            select(note2, SELECT_SINGLE, 0);
+            }
       endCmd();
       }
 
@@ -1298,40 +1453,82 @@ void Score::cmdDeleteSelection()
 void ScoreView::chordTab(bool back)
       {
       Harmony* cn      = (Harmony*)editObject;
+      Score* score = cn->score();
       Measure* measure = (Measure*)cn->parent();
-      Segment* segment = measure->tick2segment(cn->tick());
+      Segment* segment = 0;
       int track        = cn->track();
-      if (segment == 0) {
-            printf("chordTab: no segment\n");
-            return;
-            }
-
+      int tick = cn->tick();
+      
       // search next chord
       if (back) {
-            while ((segment = segment->prev1())) {
-                  if (segment->subtype() == SegChordRest)
-                        break;
+            for (segment = measure->last(); segment; segment = segment->prev1()) {
+                  if (segment->tick() < tick) {
+                        SegmentType t = SegmentType(segment->subtype());
+                        if (t == SegChordRest)
+                              break;
+                        }
                   }
             }
       else {
-            while ((segment = segment->next1())) {
-                  if (segment->subtype() == SegChordRest)
-                        break;
+            for (segment = measure->first(); segment; segment = segment->next()) {
+                  if (segment->tick() > tick) {
+                        SegmentType t = SegmentType(segment->subtype());
+                        if (t == SegChordRest)
+                              break;
+                        }
                   }
             }
-      if (segment == 0) {
-            printf("no next segment\n");
-            return;
+           
+      
+      //check if beat is closer
+       //get time sig
+       Fraction f = measure->fraction();
+      int beatsPerMeasure = (f.numerator() > 3 && f.numerator() % 3 == 0 && f.denominator() > 4) ? 
+            f.numerator() / 3 : f.numerator(); 
+      
+      int beat = measure->fraction().ticks() / beatsPerMeasure;
+      
+      int newTick = tick;
+      if (back) {
+            if(tick == measure->tick()) {
+                  //find last beat of previous measure, possibly different timesig
+                  Measure* prev = measure->prevMeasure();
+                  if(prev) {
+                        f = prev->fraction();
+                        beatsPerMeasure = (f.numerator() > 3 && f.numerator() % 3 == 0 && f.denominator() > 4) ? 
+                            f.numerator() / 3 : f.numerator(); 
+                        beat = prev->fraction().ticks() / beatsPerMeasure;
+                        newTick = prev->tick() + (beatsPerMeasure -1) * beat;
+                        }
+                  }
+            else {
+                  newTick = measure->tick()  + (((tick - 1 - measure->tick()) / beat)) * beat;
+                  }
+            
+            if(segment && segment->tick() > newTick) {
+                  newTick = segment->tick();
+                  }
+            }
+      else {
+            newTick = measure->tick()  + (((tick - measure->tick()) / beat) + 1) * beat;
+            if(newTick > measure->tick() + measure->tickLen()){
+                  chordTabTab(back); // first beat of next measure
+                  }
+            if(segment && segment->tick() < newTick) {
+                  newTick = segment->tick();
+                  }
             }
       endEdit();
+      if(newTick < 0 || newTick >= score->lastMeasure()->tick() + score->lastMeasure()->tickLen())
+            return;
       _score->startCmd();
 
       // search for next chord name
       cn              = 0;
-      measure         = segment->measure();
+      measure         = score->tick2measure(newTick);
       ElementList* el = measure->el();
       foreach(Element* e, *el) {
-            if (e->type() == HARMONY && e->tick() == segment->tick()) {
+            if (e->type() == HARMONY && e->tick() == newTick && e->track() == track) {
                   cn = static_cast<Harmony*>(e);
                   break;
                   }
@@ -1339,7 +1536,53 @@ void ScoreView::chordTab(bool back)
 
       if (!cn) {
             cn = new Harmony(_score);
-            cn->setTick(segment->tick());
+            cn->setTick(newTick);
+            cn->setTrack(track);
+            cn->setParent(measure);
+            _score->undoAddElement(cn);
+            }
+
+      _score->select(cn, SELECT_SINGLE, 0);
+      startEdit(cn, -1);
+      adjustCanvasPosition(cn, false);
+      ((Harmony*)editObject)->moveCursorToEnd();
+
+      _score->setLayoutAll(true);
+      }
+
+void ScoreView::chordTabTab(bool back)
+      {
+      Harmony* cn      = (Harmony*)editObject;
+      Measure* measure = (Measure*)cn->parent();
+      int track        = cn->track();
+      
+      Measure* m = 0;
+      if(back)
+            m = measure->prevMeasure();
+      else
+            m = measure->nextMeasure();
+            
+      endEdit();
+      if(!m)
+            return;
+            
+      _score->startCmd();
+
+      // search for next chord name
+      int newTick     = m->tick();
+      cn              = 0;
+      measure         = m;
+      ElementList* el = measure->el();
+      foreach(Element* e, *el) {
+            if (e->type() == HARMONY && e->tick() == newTick && e->track() == track) {
+                  cn = static_cast<Harmony*>(e);
+                  break;
+                  }
+            }
+
+      if (!cn) {
+            cn = new Harmony(_score);
+            cn->setTick(newTick);
             cn->setTrack(track);
             cn->setParent(measure);
             _score->undoAddElement(cn);
@@ -1416,6 +1659,11 @@ void ScoreView::cmdTuplet(int n)
       _score->startCmd();
       if (noteEntryMode()) {
             _score->expandVoice();
+            //stop creating tuplets
+            if(_score->inputState().cr()->fraction() <= Fraction(1,128)) {
+                  _score->endCmd();
+                  return; 
+                  }
             _score->changeCRlen(_score->inputState().cr(), _score->inputState().duration());
             if (_score->inputState().cr())
                   cmdTuplet(n, _score->inputState().cr());
@@ -1433,7 +1681,7 @@ void ScoreView::cmdTuplet(int n)
                         }
                   if (e->isChordRest()) {
                         ChordRest* cr = static_cast<ChordRest*>(e);
-                        if(!set.contains(cr)) {
+                        if(!set.contains(cr) && cr->fraction() > Fraction(1,128)) {
                               cmdTuplet(n, cr);
                               set.insert(cr);
                               }
@@ -1745,7 +1993,7 @@ void Score::removeChordRest(ChordRest* cr, bool clearSegment)
             Beam* beam = cr->beam();
             if (beam->generated()) {
                   beam->parent()->remove(beam);
-                  delete beam;
+                  //delete beam; // can be in selection or in undo stack ...
                   }
             else {
                   undoRemoveElement(beam);
