@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: element.cpp 3892 2011-01-15 15:47:03Z lasconic $
+//  $Id: element.cpp 4362 2011-06-11 13:04:43Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -509,7 +509,7 @@ bool Element::readProperties(QDomElement e)
             setTrack((_track/VOICES)*VOICES + i);
       else if (tag == "track")
             setTrack(i);
-      else if (tag == "selected")
+      else if (tag == "selected" && isEditable())
             setSelected(i);
       else if (tag == "color")
             _color = readColor(e);
