@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: file.cpp 3957 2011-01-29 13:40:15Z wschweer $
+//  $Id: file.cpp 4466 2011-07-03 20:34:25Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -83,7 +83,7 @@
  working directory \a base
  and filter \a ext.
  If a file is selected, load it.
- Return false if OK and true on error.
+ Return true if OK and false on error.
  */
 
 bool LoadFile::load(QWidget* parent, const QString& base, const QString& ext,
@@ -93,7 +93,7 @@ bool LoadFile::load(QWidget* parent, const QString& base, const QString& ext,
       _name = QFileDialog::getOpenFileName(parent, caption, base, ext);
 
       if (_name.isEmpty())
-            return true;
+            return false;
       QFileInfo info(_name);
 
       if (info.suffix().isEmpty()) {
@@ -106,30 +106,32 @@ bool LoadFile::load(QWidget* parent, const QString& base, const QString& ext,
 /**
  Load file \a name.
  Display message box with error if loading fails.
- Return false if OK and true on error.
+ Return true if OK and false on error.
  */
 
 bool LoadFile::load(const QString& name)
       {
       if (name.isEmpty())
-            return true;
+            return false;
 
       QFile fp(name);
       if (!fp.open(QIODevice::ReadOnly)) {
             QMessageBox::warning(0,
                QWidget::tr("MuseScore: file not found:"),
                name,
-               QString::null, QWidget::tr("Quit"), QString::null, 0, 1);
-            return true;
+               QString::null, QString::null, QString::null, 0, 1);
+            return false;
             }
-      if (loader(&fp)) {
+      if (!loader(&fp)) {
             QMessageBox::warning(0,
                QWidget::tr("MuseScore: load failed:"),
                error,
                QString::null, QWidget::tr("Quit"), QString::null, 0, 1);
+               fp.close();
+               return false;
             }
       fp.close();
-      return false;
+      return true;
       }
 
 //---------------------------------------------------------
@@ -923,7 +925,7 @@ void Score::loadStyle()
       {
       QString fn = QFileDialog::getOpenFileName(
          0, QWidget::tr("MuseScore: Load Style"),
-         QString("."),
+         QString("%1styles").arg(mscoreGlobalShare),
             QWidget::tr("MuseScore Styles (*.mss);;"
             "All Files (*)"
             )
@@ -1190,7 +1192,7 @@ bool Score::loadMsc(QString name)
 
 //---------------------------------------------------------
 //   read
-//    return false on error
+//    return false on error, return true on success
 //---------------------------------------------------------
 
 bool Score::read(QDomElement e)
@@ -1229,7 +1231,7 @@ bool Score::read(QDomElement e)
                   else if (tag == "tempolist")
                         _tempomap->read(ee, _fileDivision);
                   else if (tag == "programVersion") {
-                        QRegExp re("(\\d+)\\.(\\d+)\\.(\\d+)");
+                        QRegExp re("(\\d+)\\.(\\d+)\\.?(\\d?)");
                         int v1, v2, v3, rv1, rv2, rv3;
                         if (re.indexIn(VERSION) != -1) {
                               QStringList sl = re.capturedTexts();
