@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: icons.cpp 3879 2011-01-12 14:49:14Z lasconic $
+//  $Id: icons.cpp 4536 2011-07-16 17:01:09Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -148,7 +148,7 @@ void genIcons()
       icons[fileSave_ICON]   = new QIcon(":/data/filesave.svg");
       icons[fileSaveAs_ICON] = new QIcon(":/data/filesaveas.svg");
       icons[exit_ICON]       = new QIcon(":/data/exit.svg");
-      icons[viewmag_ICON]    = new QIcon(":/data/viewmag.xpm");
+      icons[viewmag_ICON]    = new QIcon(":/data/viewmag.svg");
       icons[repeat_ICON]     = new QIcon(":/data/repeat.svg");
       icons[noteEntry_ICON]  = new QIcon(":/data/noteentry.svg");
       icons[grace4_ICON]     = new QIcon(":/data/grace4.svg");
@@ -157,5 +157,6 @@ void genIcons()
       icons[keys_ICON]       = new QIcon(":/data/keyboard.svg");
       icons[tie_ICON]        = new QIcon(":/data/tie.svg");
       icons[window_ICON]     = new QIcon(":/data/mscore.xpm");
+      icons[community_ICON]     = new QIcon(":/data/community.svg");
       }
 
