@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: image.cpp 3173 2010-06-15 10:01:05Z lasconic $
+//  $Id: image.cpp 4453 2011-07-01 13:05:23Z lasconic $
 //
 //  Copyright (C) 2007 Werner Schweer and others
 //
@@ -61,7 +61,7 @@ void Image::dereference()
 void Image::draw(QPainter& p) const
       {
       p.drawPixmap(0, 0, buffer);
-      if (selected()) {
+      if (selected() && !(score() && score()->printing())) {
             p.setBrush(Qt::NoBrush);
             p.setPen(QPen(Qt::blue, 0, Qt::SolidLine));
             p.drawRect(QRect(QPoint(), buffer.size()));
@@ -273,15 +273,22 @@ RasterImage* RasterImage::clone() const
 void RasterImage::draw(QPainter& p) const
       {
       p.save();
-      QTransform t = p.worldTransform();
-      QSize s = QSizeF(sz.width() * t.m11(), sz.height() * t.m22()).toSize();
-      t.setMatrix(1.0, t.m12(), t.m13(), t.m21(), 1.0, t.m23(), t.m31(), t.m32(), t.m33());
-      p.setWorldTransform(t);
-      if (buffer.size() != s || _dirty) {
-            buffer = QPixmap::fromImage(doc.scaled(s, Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
-            _dirty = false;
+      if (score()->printing()) {
+            // use original image size for printing
+            p.scale(sz.width() / doc.width(), sz.height() / doc.height());
+            p.drawPixmap(0, 0, QPixmap::fromImage(doc));
+            }
+      else {
+            QTransform t = p.worldTransform();
+            QSize s = QSizeF(sz.width() * t.m11(), sz.height() * t.m22()).toSize();
+            t.setMatrix(1.0, t.m12(), t.m13(), t.m21(), 1.0, t.m23(), t.m31(), t.m32(), t.m33());
+            p.setWorldTransform(t);
+            if (buffer.size() != s || _dirty) {
+                  buffer = QPixmap::fromImage(doc.scaled(s, Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+                  _dirty = false;
+                  }
+            Image::draw(p);
             }
-      Image::draw(p);
       p.restore();
       }
 
