@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: keysig.h 3269 2010-07-09 20:20:39Z lasconic $
+//  $Id: keysig.h 3832 2011-01-04 12:13:26Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -42,6 +42,8 @@ struct KeySym {
       };
 
 class KeySig : public Element {
+      bool	_showCourtesySig;
+      bool	_showNaturals;
       QList<KeySym*> keySymbols;
       void addLayout(int sym, double x, int y);
 
@@ -70,6 +72,13 @@ class KeySig : public Element {
       bool operator==(const KeySig&) const;
       void changeType(KeySigEvent);
       void setSubtype(KeySigEvent e)  { Element::setSubtype(e.subtype); }
+
+      bool showCourtesySig() const    { return _showCourtesySig; };
+      bool showNaturals() const       { return _showNaturals;    };
+      void setShowCourtesySig(bool v) { _showCourtesySig = v;    };
+      void setShowNaturals(bool v)    { _showNaturals = v;       };
+      virtual bool genPropertyMenu(QMenu*) const;
+      virtual void propertyAction(ScoreView*, const QString&);
       };
 
 extern const char* keyNames[15];
