@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: layout.cpp 3908 2011-01-17 11:44:39Z lasconic $
+//  $Id: layout.cpp 4449 2011-06-30 13:06:36Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -78,8 +78,9 @@ void Score::rebuildBspTree()
 
       int n = el.size();
       bspTree.initialize(r, n);
-      for (int i = 0; i < n; ++i)
+      for (int i = 0; i < n; ++i) {
             bspTree.insert(el.at(i));
+            }
       }
 
 //---------------------------------------------------------
@@ -635,7 +636,7 @@ void Score::layoutStage2()
       foreach (Beam* beam, _beams) {
             if (beam->elements().isEmpty()) {
                   remove(beam);
-                  delete beam;
+                  //delete beam;  // can be in selection or in undo stack ...
                   }
             }
       }
