@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: menus.cpp 3923 2011-01-19 14:54:58Z wschweer $
+//  $Id: menus.cpp 4434 2011-06-28 09:51:39Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -471,6 +471,8 @@ void MuseScore::showPalette(bool visible)
             sp->setDrawGrid(true);
             for (int i = 0; i < HEAD_GROUPS; ++i) {
                   int sym = noteHeads[0][i][1];
+                  if (i == HEAD_BREVIS_ALT)
+                        sym = noteHeads[0][i][3];
                   NoteHead* nh = new NoteHead(gscore);
                   nh->setSym(sym);
                   sp->append(nh, qApp->translate("symbol", symbols[sym].name()));
