@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: note.cpp 3991 2011-02-03 16:43:35Z lasconic $
+//  $Id: note.cpp 4464 2011-07-03 15:45:09Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -71,6 +71,8 @@ const int noteHeads[2][HEAD_GROUPS][4] = {
       { d0faHeadSym,          d1faHeadSym,         d2faHeadSym,       -1                   },
       { s0laHeadSym,          s1laHeadSym,         s2laHeadSym,       -1                   },
       { s0tiHeadSym,          d1tiHeadSym,         d2tiHeadSym,       -1                   },
+      { s0solHeadSym,         s1solHeadSym,        s2solHeadSym,      -1                   },
+      { wholeheadSym,         halfheadSym,         quartheadSym,      brevisheadaltSym     },
       },
       {     // up stem
       { wholeheadSym,         halfheadSym,         quartheadSym,      brevisheadSym        },
@@ -85,6 +87,8 @@ const int noteHeads[2][HEAD_GROUPS][4] = {
       { u0faHeadSym,          u1faHeadSym,         u2faHeadSym,       -1                   },
       { s0laHeadSym,          s1laHeadSym,         s2laHeadSym,       -1                   },
       { s0tiHeadSym,          u1tiHeadSym,         u2tiHeadSym,       -1                   },
+      { s0solHeadSym,         s1solHeadSym,        s2solHeadSym,      -1                   },
+      { wholeheadSym,         halfheadSym,         quartheadSym,      brevisheadaltSym     },
       }
       };
 
@@ -682,6 +686,8 @@ void Note::read(QDomElement e)
                   setUserAccidental(i);
             else if (tag == "Accidental") {
                   Accidental* a = new Accidental(score());
+                  // the accidental needs to know the properties of the track it belongs to
+                  a->setTrack(track());
                   a->read(e);
                   add(a);
                   }
@@ -806,7 +812,7 @@ void ShadowNote::draw(QPainter& p) const
       qreal lw = point(score()->styleS(ST_ledgerLineWidth));
       InputState ps = score()->inputState();
       int voice;
-      if (ps.drumNote() != -1 && ps.drumset())
+      if (ps.drumNote() != -1 && ps.drumset() && ps.drumset()->isValid(ps.drumNote()))
             voice = ps.drumset()->voice(ps.drumNote());
       else
             voice = ps.voice();
@@ -971,7 +977,7 @@ Element* Note::drop(ScoreView* view, const QPointF& p1, const QPointF& p2, Eleme
                   int group = -1;
 
                   for (int i = 0; i < HEAD_GROUPS; ++i) {
-                        if (noteHeads[0][i][1] == s->sym()) {
+                        if (noteHeads[0][i][1] == s->sym() || noteHeads[0][i][3] == s->sym()) {
                               group = i;
                               break;
                               }
