@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: page.cpp 3233 2010-06-28 12:54:32Z wschweer $
+//  $Id: page.cpp 3940 2011-01-22 14:41:39Z lvinken $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -54,6 +54,14 @@ Page::~Page()
       delete _copyright;
       }
 
+//---------------------------------------------------------
+//   isOdd
+//---------------------------------------------------------
+bool Page::isOdd() const
+      {
+      return (_no+1 + _score->pageFormat()->_pageOffset) & 1;
+      }
+
 //---------------------------------------------------------
 //   tm
 //---------------------------------------------------------
@@ -119,7 +127,7 @@ void Page::layout()
       setbbox(QRectF(0.0, 0.0, loWidth(), loHeight()));
 
       // add page number
-      int n = no() + 1 + _score->_pageOffset;
+      int n = no() + 1 + _score->pageFormat()->_pageOffset;
       if (score()->styleB(ST_showPageNumber) && ((n > 1) || score()->styleB(ST_showPageNumberOne))) {
             int subtype = (n & 1) ? TEXT_PAGE_NUMBER_ODD : TEXT_PAGE_NUMBER_EVEN;
             int style   = (n & 1) ? TEXT_STYLE_PAGE_NUMBER_ODD : TEXT_STYLE_PAGE_NUMBER_EVEN;
@@ -282,7 +290,8 @@ PageFormat::PageFormat()
    oddTopMargin(10.0 / INCH),
    oddBottomMargin(20.0 / INCH),
    landscape(preferences.landscape),
-   twosided(preferences.twosided)
+   twosided(preferences.twosided),
+   _pageOffset(0)
       {
       }
 
@@ -389,6 +398,8 @@ void PageFormat::read(QDomElement e)
                   size = paperSizeNameToIndex("Custom");
                   _width = val.toDouble() * .5 / PPI;
                   }
+            else if (tag == "page-offset")
+                  _pageOffset = val.toInt();
             else
                   domError(e);
             }
@@ -460,10 +471,7 @@ void PageFormat::readMusicXML(QDomElement e, double conversion)
             else
                   domError(e);
             }
-      printf("PageFormat::readMusicXML size=%d, height=%g, width=%g\n",
-      size, _height, _width);
       int match = paperSizeSizeToIndex(_width, _height);
-      printf("PageFormat::readMusicXML match=%d\n", match);
       if (match >= 0) size = match;
       }
 
@@ -508,6 +516,8 @@ void PageFormat::write(Xml& xml)
       xml.tag("bottom-margin", oddBottomMargin * t);
       xml.etag();
 
+      xml.tag("page-offset", _pageOffset);
+      
       xml.etag();
       }
 
