@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: palette.cpp 3758 2010-12-13 14:52:53Z wschweer $
+//  $Id: palette.cpp 4560 2011-07-20 09:54:10Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -239,7 +239,9 @@ void Palette::mouseDoubleClickEvent(QMouseEvent* ev)
       else if (sel.state() == SEL_RANGE) {
             int track1 = sel.staffStart() * VOICES;
             int track2 = sel.staffEnd() * VOICES;
-            for (Segment* s = sel.startSegment(); s && s != sel.endSegment(); s = s->next1()) {
+            Segment* ss = sel.startSegment();
+            Segment* es = sel.endSegment();
+            for (Segment* s = ss; s && s != es; s = s->next1()) {
                   for (int track = track1; track < track2; ++track) {
                         Element* e = s->element(track);
                         if (e == 0)
@@ -660,7 +662,7 @@ void Palette::dropEvent(QDropEvent* event)
                   else
                         return;
                   qreal mag = PALETTE_SPATIUM * extraMag / gscore->spatium();
-                  s->setPath(u.path());
+                  s->setPath(u.toLocalFile());
                   s->setSize(QSizeF(hgrid / mag, hgrid / mag));
                   e = s;
                   name = s->path();
