@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: preferences.cpp 3676 2010-11-05 11:39:46Z lasconic $
+//  $Id: preferences.cpp 4585 2011-07-24 06:27:19Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -111,7 +111,7 @@ Preferences::Preferences()
 void Preferences::init()
       {
       // set fallback defaults:
-
+      
       bgUseColor         = true;
       fgUseColor         = false;
       bgWallpaper        = QString();
@@ -137,8 +137,8 @@ void Preferences::init()
       rPort              = "";
       showNavigator      = true;
       showPlayPanel      = false;
+      showWebPanel       = true;
       showStatusBar      = true;
-      playPanelPos       = QPoint(100, 300);
 
 #if defined(Q_WS_MAC) || defined(__MINGW32__)
       useAlsaAudio       = false;
@@ -210,7 +210,7 @@ void Preferences::init()
       tuning                  = 440.0f;
       masterGain              = 0.2;
       chorusGain              = 0.5;
-      reverbGain              = 0.5;
+      reverbGain              = 0.2;
       reverbRoomSize          = 0.5;
       reverbDamp              = 0.5;
       reverbWidth             = 1.0;
@@ -222,6 +222,8 @@ void Preferences::init()
 
       //update
       checkUpdateStartup      = 0;
+      
+      firstStartWeb = true;
       };
 
 //---------------------------------------------------------
@@ -254,6 +256,7 @@ void Preferences::write()
       s.setValue("rPort",              rPort);
       s.setValue("showNavigator",      showNavigator);
       s.setValue("showPlayPanel",      showPlayPanel);
+      s.setValue("showWebPanel",       showWebPanel);
       s.setValue("showStatusBar",      showStatusBar);
 
       s.setValue("useAlsaAudio",       useAlsaAudio);
@@ -322,14 +325,12 @@ void Preferences::write()
       s.setValue("importCharset", importCharset);
       s.setValue("warnPitchRange", warnPitchRange);
       s.setValue("followSong", followSong);
+      
+      s.setValue("firstStartWeb", firstStartWeb);
 
       //update
       s.setValue("checkUpdateStartup", checkUpdateStartup);
 
-      s.beginGroup("PlayPanel");
-      s.setValue("pos", playPanelPos);
-      s.endGroup();
-
       writeShortcuts();
       }
 
@@ -360,15 +361,16 @@ void Preferences::read()
       playNotes       = s.value("playNotes", true).toBool();
       lPort           = s.value("lPort").toString();
       rPort           = s.value("rPort").toString();
-
-      soundFont       = s.value("soundFont", mscoreGlobalShare+"/sound/TimGM6mb.sf2").toString();
+      defaultSoundfont = mscoreGlobalShare+"sound/TimGM6mb.sf2";
+      soundFont       = s.value("soundFont", defaultSoundfont).toString();
       if (soundFont == ":/data/piano1.sf2") {
             // silently change to new default sound font
-            soundFont = mscoreGlobalShare + "/sound/TimGM6mb.sf2";
+            soundFont = defaultSoundfont;
             }
       showNavigator   = s.value("showNavigator", true).toBool();
       showStatusBar   = s.value("showStatusBar", true).toBool();
       showPlayPanel   = s.value("showPlayPanel", false).toBool();
+      showWebPanel    = s.value("showWebPanel", true).toBool();
 
 #if defined(Q_WS_MAC) || defined(__MINGW32__)
       useAlsaAudio       = s.value("useAlsaAudio", false).toBool();
@@ -423,7 +425,7 @@ void Preferences::read()
       tuning                 = s.value("tuning", 440.0).toDouble();
       masterGain             = s.value("masterGain", 0.2).toDouble();
       chorusGain             = s.value("chorusGain", 0.5).toDouble();
-      reverbGain             = s.value("reverbGain", 0.5).toDouble();
+      reverbGain             = s.value("reverbGain", 0.2).toDouble();
       reverbRoomSize         = s.value("reverbRoomSize", 0.5).toDouble();
       reverbDamp             = s.value("reverbDamp", 0.5).toDouble();
       reverbWidth            = s.value("reverbWidth", 1.0).toDouble();
@@ -433,6 +435,8 @@ void Preferences::read()
       importCharset          = s.value("importCharset", "GBK").toString();
       warnPitchRange         = s.value("warnPitchRange", true).toBool();
       followSong             = s.value("followSong", true).toBool();
+      
+      firstStartWeb = s.value("firstStartWeb", true).toBool();
 
       checkUpdateStartup = s.value("checkUpdateStartup", UpdateChecker::defaultPeriod()).toInt();
       if (checkUpdateStartup == 0){
@@ -452,10 +456,6 @@ void Preferences::read()
       startScore     = s.value("startScore", ":/data/Promenade_Example.mscx").toString();
       instrumentList = s.value("instrumentList", ":/data/instruments.xml").toString();
 
-      s.beginGroup("PlayPanel");
-      playPanelPos = s.value("pos", QPoint(100, 300)).toPoint();
-      s.endGroup();
-
       readShortcuts();
       }
 
@@ -481,8 +481,6 @@ PreferenceDialog::PreferenceDialog(QWidget* parent)
    : QDialog(parent)
       {
       setupUi(this);
-      characterSetGroupBox->setVisible(false);
-
       shortcutsChanged        = false;
 
 #ifndef USE_JACK
@@ -518,7 +516,6 @@ PreferenceDialog::PreferenceDialog(QWidget* parent)
       connect(workingDirectoryButton, SIGNAL(clicked()), SLOT(selectWorkingDirectory()));
       connect(instrumentListButton,   SIGNAL(clicked()), SLOT(selectInstrumentList()));
       connect(startWithButton,        SIGNAL(clicked()), SLOT(selectStartWith()));
-      connect(playPanelCur, SIGNAL(clicked()), SLOT(playPanelCurClicked()));
       connect(shortcutList, SIGNAL(itemActivated(QTreeWidgetItem*, int)), SLOT(defineShortcutClicked()));
       connect(resetShortcut, SIGNAL(clicked()), SLOT(resetShortcutClicked()));
       connect(clearShortcut, SIGNAL(clicked()), SLOT(clearShortcutClicked()));
@@ -593,8 +590,7 @@ void PreferenceDialog::updateValues(Preferences* p)
 
       navigatorShow->setChecked(p->showNavigator);
       playPanelShow->setChecked(p->showPlayPanel);
-      playPanelX->setValue(p->playPanelPos.x());
-      playPanelY->setValue(p->playPanelPos.y());
+      webPanelShow->setChecked(p->showWebPanel);
 
       alsaDriver->setChecked(p->useAlsaAudio);
       jackDriver->setChecked(p->useJackAudio);
@@ -839,7 +835,22 @@ void PreferenceDialog::updateSCListView()
 
 void PreferenceDialog::resetShortcutClicked()
       {
-      printf("resetShortcutClicked\n");
+      QTreeWidgetItem* active = shortcutList->currentItem();
+      if (!active)
+            return;
+      QString str = active->data(0, Qt::UserRole).toString();
+      if (str.isEmpty())
+            return;
+      Shortcut* shortcut = localShortcuts[str];
+
+      for (unsigned i = 0;; ++i) {
+            if (MuseScore::sc[i].xml == shortcut->xml) {
+                  shortcut->key = MuseScore::sc[i].key;
+                  active->setText(1, shortcut->key.toString(QKeySequence::NativeText));
+                  shortcutsChanged = true;
+                  break;
+                  }
+            }
       }
 
 //---------------------------------------------------------
@@ -937,7 +948,7 @@ void PreferenceDialog::selectInstrumentList()
       QString s = QFileDialog::getOpenFileName(
          this,
          tr("Choose Instrument List"),
-         instrumentList->text(),
+         mscoreGlobalShare + "templates",
          tr("Instrument List (*.xml)")
          );
       if (!s.isNull())
@@ -1030,7 +1041,8 @@ void PreferenceDialog::apply()
             }
       preferences.showNavigator      = navigatorShow->isChecked();
       preferences.showPlayPanel      = playPanelShow->isChecked();
-      preferences.playPanelPos       = QPoint(playPanelX->value(), playPanelY->value());
+      preferences.showWebPanel       = webPanelShow->isChecked();
+
       preferences.antialiasedDrawing = drawAntialiased->isChecked();
 
       if (
@@ -1179,20 +1191,6 @@ void PreferenceDialog::apply()
       mscore->startAutoSave();
       }
 
-//---------------------------------------------------------
-//   playPanelCurClicked
-//---------------------------------------------------------
-
-void PreferenceDialog::playPanelCurClicked()
-      {
-      PlayPanel* w = mscore->getPlayPanel();
-      if (w == 0)
-            return;
-      QPoint s(w->pos());
-      playPanelX->setValue(s.x());
-      playPanelY->setValue(s.y());
-      }
-
 //---------------------------------------------------------
 //   writeShortcuts
 //---------------------------------------------------------
