@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: preferences.h 3276 2010-07-12 09:29:28Z lasconic $
+//  $Id: preferences.h 4455 2011-07-01 15:23:33Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -55,14 +55,15 @@ struct Preferences {
       QColor defaultColor;
       QColor dropColor;
       bool enableMidiInput;
-      bool playNotes;         // play notes on click
-      QString soundFont;      // sound font used by synthesizer
-      QString lPort;          // audio port left
-      QString rPort;          // audio port right
+      bool playNotes;           // play notes on click
+      QString defaultSoundfont; // store the default soundfont for fallback
+      QString soundFont;        // sound font used by synthesizer
+      QString lPort;            // audio port left
+      QString rPort;            // audio port right
       bool showNavigator;
       bool showPlayPanel;
+      bool showWebPanel;
       bool showStatusBar;
-      QPoint playPanelPos;
 
       bool useAlsaAudio;
       bool useJackAudio;
@@ -127,6 +128,8 @@ struct Preferences {
       bool warnPitchRange;
       bool followSong;
 
+      bool firstStartWeb;
+
       bool dirty;
 
       Preferences();
@@ -172,7 +175,6 @@ class PreferenceDialog : public QDialog, private Ui::PrefsDialogBase {
       void selectWorkingDirectory();
       void selectInstrumentList();
       void selectStartWith();
-      void playPanelCurClicked();
       void resetShortcutClicked();
       void clearShortcutClicked();
       void defineShortcutClicked();
