@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: score.cpp 3794 2010-12-22 22:38:11Z lasconic $
+//  $Id: score.cpp 4136 2011-03-30 19:54:49Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -373,11 +373,15 @@ bool Score::read(QString name)
                   }
 
             if (csl == "xml") {
-                  importMusicXml(name);
+                  if (!importMusicXml(name))
+                        return false;
+                  connectSlurs();
+                  }
+            else if (csl == "mxl") {
+                  if (!importCompressedMusicXml(name))
+                        return false;
                   connectSlurs();
                   }
-            else if (csl == "mxl")
-                  importCompressedMusicXml(name);
             else if (csl == "mid" || csl == "midi" || csl == "kar") {
                   if (!importMidi(name))
                         return false;
