@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: score.h 3794 2010-12-22 22:38:11Z lasconic $
+//  $Id: score.h 4439 2011-06-28 12:11:24Z lasconic $
 //
 //  Copyright (C) 2002-2010 Werner Schweer and others
 //
@@ -495,6 +495,7 @@ class Score : public QObject {
       void removeElement(Element*);
 
       void addTimeSig(int tick, int keySigSubtype);
+      void insertTimeSig(int tick, TimeSig* ts);
 
       void cmdAdd1(Element* e, const QPointF& pos, const QPointF& dragOffset);
       void cmdAddBSymbol(BSymbol*, const QPointF&, const QPointF&);
@@ -544,8 +545,8 @@ class Score : public QObject {
 
       bool loadMsc(QString name);
       bool loadCompressedMsc(QString name);
-      void importMusicXml(const QString&);
-      void importCompressedMusicXml(const QString&);
+      bool importMusicXml(const QString&);
+      bool importCompressedMusicXml(const QString&);
       bool importMidi(const QString& name);
       bool importMuseData(const QString& name);
       bool importLilypond(const QString& name);
@@ -589,6 +590,7 @@ class Score : public QObject {
       bool playlistDirty();
       void setPlaylistDirty(bool val) { _playlistDirty = val; }
       void changeTimeSig(int tick, int st);
+      void replaceTimeSig(int tick, TimeSig* ts);
 
       void cmd(const QAction*);
       int fileDivision(int t) const { return (t * AL::division + _fileDivision/2) / _fileDivision; }
