@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: scscore.cpp 3801 2010-12-23 12:12:27Z lasconic $
+//  $Id: scscore.cpp 4439 2011-06-28 12:11:24Z lasconic $
 //
 //  Copyright (C) 2009-2010 Werner Schweer and others
 //
@@ -35,25 +35,27 @@
 #include "script.h"
 #include "score.h"
 #include "repeatlist.h"
+#include "timesig.h"
 
 Q_DECLARE_METATYPE(PageFormat*);
 Q_DECLARE_METATYPE(Score*);
 Q_DECLARE_METATYPE(Part*);
 Q_DECLARE_METATYPE(Text*);
+Q_DECLARE_METATYPE(TimeSig*);
 
 static const char* const function_names_score[] = {
       "title", "subtitle", "composer", "poet",
       "load", "save",
       "setExpandRepeat", "appendPart", "appendMeasures",
       "pages", "measures", "parts", "part", "startUndo", "endUndo", "setStyle", "hasLyrics", "hasHarmonies",
-      "staves", "keysig", "duration", "pageFormat", "source"
+      "staves", "keysig", "duration", "pageFormat", "source", "timesig"
       };
 static const int function_lengths_score[] = {
       1, 1, 1, 1,
       1, 6,
       1, 1, 1,
       0, 0, 0, 1, 0, 0, 2, 0, 0,
-      0, 0, 0, 0, 1
+      0, 1, 0, 0, 1, 1
       };
 
 static const QScriptValue::PropertyFlags flags_score[] = {
@@ -80,10 +82,11 @@ static const QScriptValue::PropertyFlags flags_score[] = {
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
 
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
-      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
+      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
+      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter
       };
 
 ScriptInterface scoreInterface = {
@@ -395,6 +398,19 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                             }
                         return qScriptValueFromValue(context->engine(), result);
                         }
+                  else if(argc == 1) {
+                        int newKey = context->argument(0).toInt32();
+                        KeySigEvent ke;
+                        ke.setAccidentalType(newKey);
+    
+                        for (int idx = 0; idx < score->nstaves(); idx++) {
+                            int curKey = score->staff(idx)->key(0).accidentalType();
+                            if (curKey != newKey) {
+                                score->staff(idx)->changeKeySig(0, ke);
+                            }
+                        }
+                        return context->engine()->undefinedValue();
+                        }
                   break;
             case 20:   //duration
                   if (argc == 0){
@@ -419,6 +435,26 @@ static QScriptValue prototype_Score_call(QScriptContext* context, QScriptEngine*
                         return context->engine()->undefinedValue();
                   }
                   break;
+            case 23:  // timesig
+                  if (argc == 0) {
+                        TimeSig* t = 0;
+                        Segment* s = 0;
+                        Measure* m = score->firstMeasure();
+                        if (m && (s = m->first(SegTimeSig)))
+                              t = static_cast<TimeSig*>(s->element(0));
+                        return qScriptValueFromValue(context->engine(), t);
+                  }
+                  else if (argc == 1) {
+                      TimeSig* timesig = qscriptvalue_cast<TimeSig*>(context->argument(0));
+                      if (!timesig)
+                            break;
+                      if (timesig->subtype() != 0)
+                          score->replaceTimeSig(0, timesig);
+                      return context->engine()->undefinedValue();
+                  }
+
+                  break;
+
             }
       return context->throwError(QScriptContext::TypeError,
          QString::fromLatin1("Score.%0(): bad argument count or value")
