@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: select.cpp 2969 2010-04-15 11:17:10Z wschweer $
+//  $Id: select.cpp 4493 2011-07-07 07:12:32Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -199,6 +199,8 @@ void Selection::clear()
             _score->addRefresh(e->abbox());
             }
       _el.clear();
+      setStartSegment(0);
+      setEndSegment(0);
       setState(SEL_NONE);
       }
 
