@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: seq.cpp 3727 2010-11-24 15:48:07Z lasconic $
+//  $Id: seq.cpp 4157 2011-04-11 08:48:48Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -231,12 +231,19 @@ bool Seq::init()
                         printf("load soundfont <%s>\n", qPrintable(p));
                   bool rv = synth->loadSoundFont(p);
                   if (!rv) {
-                        QString s = tr("Loading SoundFont\n"
-                           "\"%1\"\n"
-                           "failed. Playback will be disabled.\n\n"
-                           "Go to Display > Synthesizer \n"
-                           "and check that the file location is correct").arg(p);
-                        QMessageBox::critical(0, tr("MuseScore: Load SoundFont"), s);
+                        //try to load the default soundfont, it should be there
+                        p = preferences.defaultSoundfont;
+                        rv = synth->loadSoundFont(p);
+                        if (!rv) {
+                              QString s = tr("Loading SoundFont\n"
+                                 "\"%1\"\n"
+                                 "failed. Playback will be disabled.\n\n"
+                                 "Go to Display > Synthesizer \n"
+                                 "and check that the file location is correct").arg(p);
+                              QMessageBox::critical(0, tr("MuseScore: Load SoundFont"), s);
+                        }else {
+                              preferences.soundFont = preferences.defaultSoundfont;
+                              }
                         }
                   }
             synth->setMasterTuning(preferences.tuning);
@@ -828,6 +835,8 @@ void Seq::seek(int tick)
       cs->setPlayPos(tick);
       cs->end();
 
+      tick = cs->repeatList()->tick2utick(tick);
+
       SeqMsg msg;
       msg.data = tick;
       msg.id   = SEQ_SEEK;
@@ -1104,17 +1113,15 @@ SeqMsgFifo::SeqMsgFifo()
 void SeqMsgFifo::enqueue(const SeqMsg& msg)
       {
       int i = 0;
-#ifdef __MINGW32__
-      int n = 500000;
-#else
       int n = 50;
-#endif
+
+      QMutex mutex;
+      QWaitCondition qwc;
+      mutex.lock();
       for (; i < n; ++i) {
             if (!isFull())
                   break;
-#ifndef __MINGW32__
-            usleep(100000);
-#endif
+            qwc.wait(&mutex,100); //wait 100ms
             }
       if (i == n) {
             printf("===SeqMsgFifo: overflow\n");
