@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: tuplet.cpp 3966 2011-02-01 11:46:15Z lasconic $
+//  $Id: tuplet.cpp 4136 2011-03-30 19:54:49Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -496,7 +496,7 @@ void Tuplet::add(Element* e)
       {
       foreach(DurationElement* el, _elements) {
             if (el == e)
-                  printf("Tuplet::add: %s already there\n", el->name());
+                  printf("Tuplet::add: %s already there %p\n", el->name(), el);
             }
 
       switch(e->type()) {
