@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: undo.cpp 3832 2011-01-04 12:13:26Z lasconic $
+//  $Id: undo.cpp 4366 2011-06-11 17:51:10Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -2120,8 +2120,22 @@ void ChangeStyle::flip()
 
       if (score->styleB(ST_concertPitch) != style[ST_concertPitch].toBool())
             score->cmdConcertPitchChanged(style[ST_concertPitch].toBool(), true);
-
+      bool chordChanged = false;
+      if (score->style(ST_chordDescriptionFile).toString() != style[ST_chordDescriptionFile].toString())
+            chordChanged = true;
+            
       score->setStyle(style);
+      
+      if (chordChanged) {
+            for (Measure* m = score->firstMeasure(); m; m = m->nextMeasure()) {
+                  foreach(Element* element, *m->el()) {
+                        if (element->type() == HARMONY) {
+                              Harmony* h = static_cast<Harmony*>(element);
+                              h->render();
+                              }
+                        }
+                  }
+            }
       style = tmp;
       }
 
