@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: utils.cpp 3915 2011-01-18 13:47:34Z wschweer $
+//  $Id: utils.cpp 4302 2011-05-20 08:27:38Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -640,7 +640,7 @@ static int _majorVersion, _minorVersion, _updateVersion;
 
 int version()
       {
-      QRegExp re("(\\d+)\\.(\\d+)\\.(\\d+)");
+      QRegExp re("(\\d+)\\.(\\d+)\\.?(\\d?)");
       if (re.indexIn(VERSION) != -1) {
             QStringList sl = re.capturedTexts();
             if (sl.size() == 4) {
